@@ -1,11 +1,11 @@
 #' Plots a network object
 #'
-#' Plots the network created using the \code{\link{netfacs.network}} function;
+#' Plots the network created using the \code{\link{netfacs_network}} function;
 #' for networks with clear clusterin of elements, clusters can get different
 #' colours
 #'
 #' @param netfacs.graph igraph network object resulting from
-#'   \code{\link{netfacs.network}}
+#'   \code{\link{netfacs_network}}
 #' @param title string of the graph's main title
 #' @param clusters if \code{TRUE}, \code{\link[igraph]{cluster_fast_greedy}} is
 #'   used to establish possible clusters in the dataset
@@ -18,18 +18,7 @@
 #'   where the size of nodes indicates how often they occur on their own, and
 #'   edges indicate significant co-occurrence between them
 #'
-#' @importFrom dplyr filter
-#' @importFrom igraph cluster_fast_greedy
-#' @importFrom ggplot2 scale_size
-#' @importFrom ggplot2 ggtitle
-#' @importFrom ggplot2 aes
-#' @importFrom ggplot2 unit
-#' @importFrom ggraph geom_node_text
-#' @importFrom ggraph geom_edge_link
-#' @importFrom ggraph theme_graph
-#' @importFrom ggraph circle
-#' @importFrom grDevices rainbow
-#' @importFrom tidygraph activate
+#' @importFrom magrittr `%>%`
 #' @export
 #'
 #' @examples
@@ -38,28 +27,25 @@
 #'   data = emotions_set[[1]],
 #'   condition = emotions_set[[2]]$emotion,
 #'   test.condition = "anger",
-#'   ran.trials = 100,
+#'   ran.trials = 10,
 #'   combination.size = 2
 #' )
 #'
-#' anger.net <- netfacs.network(
+#' anger.net <- netfacs_network(
 #'   netfacs.data = angry.face,
 #'   link = "unweighted",
 #'   significance = 0.01,
-#'   min.count = 1,
-#'   min.prob = 0,
-#'   min.specificity = 0,
-#'   ignore.element = NULL
+#'   min.count = 1
 #' )
 #'
-#' anger.plot <- network.plot(anger.net,
-#'   title = "Angry Faces",
-#'   clusters = FALSE,
-#'   plot.bubbles = TRUE
-#' )
-network.plot <- function(netfacs.graph,
+#' network_plot(anger.net,
+#'              title = "Angry Faces",
+#'              clusters = FALSE,
+#'              plot.bubbles = TRUE)
+
+network_plot <- function(netfacs.graph,
                          title = "network",
-                         clusters = TRUE,
+                         clusters = FALSE,
                          plot.bubbles = FALSE,
                          hide.unconnected = TRUE) {
   g <- netfacs.graph
@@ -68,50 +54,50 @@ network.plot <- function(netfacs.graph,
   if (hide.unconnected) {
     g <- 
       g %>% 
-      activate(nodes) %>% 
-      filter(.data$element.prob != 0 | !is.na(.data$element.prob))
+      tidygraph::activate(nodes) %>% 
+      dplyr::filter(.data$element.prob != 0 | !is.na(.data$element.prob))
   }
   
   # if 'cluster' is not selected, the graph is plotted in black and white
   if (!clusters) {
     p <- 
       g %>% 
-      ggraph(layout = "igraph",
-             algorithm = 'kk') +
-      geom_edge_link(
-        aes(label = round(.data$observed.prob, 2)),
+      ggraph::ggraph(layout = "igraph",
+                     algorithm = 'kk') +
+      ggraph::geom_edge_link(
+        ggplot2::aes(label = round(.data$observed.prob, 2)),
         arrow = NULL,
         colour = "grey",
         fontface = 'bold',
-        end_cap = circle(2, "mm"),
-        start_cap = circle(2, "mm"),
-        label_dodge = unit(2, "mm"),
+        end_cap = ggraph::circle(2, "mm"),
+        start_cap = ggraph::circle(2, "mm"),
+        label_dodge = grid::unit(2, "mm"),
         angle_calc = "along",
         show.legend = FALSE
       ) +
-      geom_node_text(
-        aes(label = .data$name,
-            size = .data$element.prob,
-            fontface = "bold"),
+      ggraph::geom_node_text(
+        ggplot2::aes(label = .data$name,
+                     size = .data$element.prob,
+                     fontface = "bold"),
         show.legend = FALSE
       ) +
-      scale_size(range = c(4, 12)) +
-      ggtitle(title) +
-      theme_graph(base_family = "sans")
+      ggplot2::scale_size(range = c(4, 12)) +
+      ggplot2::ggtitle(title) +
+      ggraph::theme_graph(base_family = "sans")
     
     if (plot.bubbles) {
       
       p <- p +
-        geom_node_point(
-          aes(size = .data$element.prob + 3, alpha = 0.01),
+        ggraph::geom_node_point(
+          ggplot2::aes(size = .data$element.prob + 3, alpha = 0.01),
           color = "lightblue",
           show.legend = FALSE
         ) +
-        coord_fixed() +
-        geom_node_text(
-          aes(label = .data$name,
-              size = .data$element.prob,
-              fontface = "bold"
+        ggplot2::coord_fixed() +
+        ggraph::geom_node_text(
+          ggplot2::aes(label = .data$name,
+                       size = .data$element.prob,
+                       fontface = "bold"
           ),
           show.legend = FALSE
         )
@@ -122,51 +108,71 @@ network.plot <- function(netfacs.graph,
   if (clusters) {
     net.un <- g
     # other clustering algorithms exist, eg walktrap
-    net.community <- cluster_fast_greedy(net.un) 
+    net.community <- igraph::cluster_fast_greedy(net.un) 
     # modularity measure. Above 0.3 is good modularity
-    modular <- round(modularity(net.community), 2) 
+    modular <- round(igraph::modularity(net.community), 2) 
     
     net.com <- data.frame(
       name = net.community$names,
       community = net.community$membership
     )
-    color <- rainbow(length(unique(net.com$community)))
+    color <- grDevices::rainbow(length(unique(net.com$community)))
     shape <- sample(rep(15:19, 10))
     
     p <- 
       g %>% 
-      ggraph(layout = "igraph", 
+      ggraph::ggraph(layout = "igraph", 
              algorithm = 'kk') +
-      geom_edge_link(aes(label = round(.data$observed.prob, 2)),
+      ggraph::geom_edge_link(aes(label = round(.data$observed.prob, 2)),
                      arrow = NULL,
                      colour = "grey",
                      fontface = 'bold',
-                     end_cap = circle(5, "mm"),
-                     start_cap = circle(5, "mm"),
-                     label_dodge = unit(2, "mm"),
+                     end_cap = ggraph::circle(5, "mm"),
+                     start_cap = ggraph::circle(5, "mm"),
+                     label_dodge = grid::unit(2, "mm"),
                      angle_calc = "along",
                      show.legend = FALSE) +
-      geom_node_text(aes(label = .data$name,
+      ggraph::geom_node_text(aes(label = .data$name,
                          color = color[net.com$community],
                          size = .data$element.prob,
                          fontface = "bold"),
                      show.legend = FALSE) +
-      scale_size(range = c(4, 12)) +
-      ggtitle(paste(c(title, "; Modularity = ", modular), collapse = "")) +
-      theme_graph(base_family = "sans")
+      ggplot2::scale_size(range = c(4, 12)) +
+      ggplot2::ggtitle(
+        paste(c(title, "; Modularity = ", modular), collapse = "")
+      ) +
+      ggraph::theme_graph(base_family = "sans")
     
     if (plot.bubbles) {
       p <- p +
-        geom_node_point(aes(size = .data$element.prob + 3, alpha = 0.01),
-                        color = color[net.com$community],
-                        shape = shape[net.com$community],
-                        show.legend = F) +
-        coord_fixed() +
-        geom_node_text(aes(label = .data$name,
-                           size = .data$element.prob,
-                           fontface = "bold"),
-                       show.legend = FALSE)
+        ggraph::geom_node_point(
+          ggplot2::aes(size = .data$element.prob + 3, alpha = 0.01),
+          color = color[net.com$community],
+          shape = shape[net.com$community],
+          show.legend = F
+        ) +
+        ggplot2::coord_fixed() +
+        ggraph::geom_node_text(
+          ggplot2::aes(label = .data$name,
+                       size = .data$element.prob,
+                       fontface = "bold"),
+          show.legend = FALSE
+        )
     }
   }
   return(p)
 }
+
+#' @rdname network_plot
+#' @export
+network.plot <- function(netfacs.graph,
+                         title = "network",
+                         clusters = FALSE,
+                         plot.bubbles = FALSE,
+                         hide.unconnected = TRUE) {
+  network_plot(netfacs.graph,
+               title,
+               clusters,
+               plot.bubbles,
+               hide.unconnected)
+}
